# connection_info


[![pub package](https://img.shields.io/pub/v/device_info_plus.svg)](https://pub.dev/packages/connection_info)


Get current internet conenction information from within the Flutter application.

## Platform Support

| Android | iOS | MacOS | Web | Linux | Windows |
| :-----: | :-: | :---: | :-: | :---: | :-----: |
|   ✔️    | ✔️  |  ✔️   | ✔️  |  ✔️   |   ✔️    |

# Usage

Import `package:connection_info/connection_info.dart`, instantiate `ConnectionController`
and listen to the stream for internet connection status or check directly using the `isConnected() async` method.

**Note:** `ConnectionState` will conflict with package `dart:async`, so we import connection state as follows:

```dart 
import 'package:connection_info/models/connection_state.dart'
    as connection_state;
```

Example:

```dart
class NetworkConnectionTestScreen extends StatefulWidget {
  const NetworkConnectionTestScreen({Key? key}) : super(key: key);

  @override
  State<NetworkConnectionTestScreen> createState() =>
      _NetworkConnectionTestScreenState();
}

class _NetworkConnectionTestScreenState
    extends State<NetworkConnectionTestScreen> {
  StreamSubscription? connectionSubscription;

  bool _isConnected = true;
  @override
  void initState() {
    super.initState();

    ConnectionController _controller = ConnectionController(
      serverUrl: 'pub.dev',
      repeatInterval: const Duration(seconds: 1),
      showErrorInDebugMode: false,
    );

    connectionSubscription = _controller.stream.listen((event) {
      print(event.isConnected);

      if (event is connection_state.ConnectionState) {
        setState(() {
          _isConnected = event.isConnected;
        });
      }
    });
  }

  @override
  void dispose() {
    super.dispose();
    connectionSubscription?.cancel();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Center(child: Text('Has Internet: $_isConnected')),
    );
  }
}
```
